changeset 1867:5ea1f7516c2c v7.2.165

updated for version 7.2-165
author vimboss
date Wed, 29 Apr 2009 16:03:38 +0000
parents c474f5691c0c
children 954947a70580
files src/fileio.c src/version.c
diffstat 2 files changed, 5 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -677,6 +677,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    165,
+/**/
     164,
 /**/
     163,
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -8785,9 +8785,11 @@ apply_autocmds_group(event, fname, fname
     else
     {
 	sfname = vim_strsave(fname);
 	/* Don't try expanding FileType, Syntax, WindowID or QuickFixCmd* */
 	if (event == EVENT_FILETYPE
 		|| event == EVENT_SYNTAX
+		|| event == EVENT_FUNCUNDEFINED
 		|| event == EVENT_REMOTEREPLY
 		|| event == EVENT_SPELLFILEMISSING
 		|| event == EVENT_QUICKFIXCMDPRE
@@ -8785,9 +8785,11 @@ apply_autocmds_group(event, fname, fname
     {
 	sfname = vim_strsave(fname);
-	/* Don't try expanding FileType, Syntax, WindowID or QuickFixCmd* */
+	/* Don't try expanding FileType, Syntax, FuncUndefined, WindowID or
+	 * QuickFixCmd* */
 	if (event == EVENT_FILETYPE
 		|| event == EVENT_SYNTAX